@@ -1,4 +1,4 @@
-from typing import Any, List, NamedTuple, Union
+from typing import Any, List, NamedTuple, Optional, Union
 
 __all__ = ["Path"]
 
@@ -10,10 +10,12 @@ class Path(NamedTuple):
     """path with the previous indices"""
     key: Union[str, int]
     """current index in the path (string or integer)"""
+    typename: Optional[str]
+    """name of the parent type to avoid path ambiguity"""
 
-    def add_key(self, key: Union[str, int]) -> "Path":
+    def add_key(self, key: Union[str, int], typename: Optional[str] = None) -> "Path":
         """Return a new Path containing the given key."""
-        return Path(self, key)
+        return Path(self, key, typename)
 
     def as_list(self) -> List[Union[str, int]]:
         """Return a list of the path keys."""
