@@ -5,7 +5,7 @@ the GraphQL language and type objects.
 """
 
 # Produce the GraphQL query recommended for a full schema introspection.
-from .get_introspection_query import get_introspection_query
+from .get_introspection_query import get_introspection_query, IntrospectionQuery
 
 # Get the target Operation from a Document.
 from .get_operation_ast import get_operation_ast
@@ -23,7 +23,7 @@ from .build_client_schema import build_client_schema
 from .build_ast_schema import build_ast_schema, build_schema
 
 # Extend an existing GraphQLSchema from a parsed GraphQL Schema language AST.
-from .extend_schema import extend_schema, get_description
+from .extend_schema import extend_schema
 
 # Sort a GraphQLSchema.
 from .lexicographic_sort_schema import lexicographic_sort_schema
@@ -33,12 +33,15 @@ from .print_schema import (
     print_introspection_schema,
     print_schema,
     print_type,
-    print_value,
+    print_value,  # deprecated
 )
 
 # Create a GraphQLType from a GraphQL language AST.
 from .type_from_ast import type_from_ast
 
+# Convert a language AST to a dictionary.
+from .ast_to_dict import ast_to_dict
+
 # Create a Python value from a GraphQL language AST with a type.
 from .value_from_ast import value_from_ast
 
@@ -81,18 +84,17 @@ from .find_breaking_changes import (
     find_dangerous_changes,
 )
 
-# Report all deprecated usages within a GraphQL document (deprecated).
-from .find_deprecated_usages import find_deprecated_usages
-
 __all__ = [
     "BreakingChange",
     "BreakingChangeType",
     "DangerousChange",
     "DangerousChangeType",
+    "IntrospectionQuery",
     "TypeInfo",
     "TypeInfoVisitor",
     "assert_valid_name",
     "ast_from_value",
+    "ast_to_dict",
     "build_ast_schema",
     "build_client_schema",
     "build_schema",
@@ -102,8 +104,6 @@ __all__ = [
     "extend_schema",
     "find_breaking_changes",
     "find_dangerous_changes",
-    "find_deprecated_usages",
-    "get_description",
     "get_introspection_query",
     "get_operation_ast",
     "get_operation_root_type",
